<?php

namespace Drupal\book_menu_sync\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\system\Entity\Menu;

/**
 * Provides a form for converting books to menus.
 */
class BookMenuConvertForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'book_menu_convert_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // Get all books
    $books = \Drupal::service('book.manager')->getAllBooks();
    
    $options = [];
    foreach ($books as $book_id => $book) {
      if (isset($book['title'])) {
        $options[$book_id] = $book['title'];
      }
    }

    $form['book'] = [
      '#type' => 'select',
      '#title' => $this->t('Select Book'),
      '#options' => $options,
      '#required' => TRUE,
      '#description' => $this->t('Choose the book to convert into menu structure'),
    ];

    $form['actions']['#type'] = 'actions';
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Convert to Menu'),
      '#button_type' => 'primary',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $book_id = $form_state->getValue('book');
    
    // Create a new menu if it doesn't exist
    $menu_id = 'book-menu-' . $book_id;
    $menu = Menu::load($menu_id);
    if (!$menu) {
      $menu = Menu::create([
        'id' => $menu_id,
        'label' => 'Book Menu ' . $book_id,
        'description' => 'Generated from book structure',
      ]);
      $menu->save();
    }
    else {
      // Clear existing menu items
      $menu_link_storage = \Drupal::entityTypeManager()->getStorage('menu_link_content');
      $menu_links = $menu_link_storage->loadByProperties(['menu_name' => $menu_id]);
      if (!empty($menu_links)) {
        $menu_link_storage->delete($menu_links);
      }
    }
    
    // Convert book to menu
    $count = book_menu_sync_convert_book_to_menu($book_id);
    
    $this->messenger()->addStatus($this->t('Successfully converted book structure to menu with @count items.', [
      '@count' => $count,
    ]));
  }

}
